@@ -28,10 +28,15 @@ from mkdocs_include_markdown_plugin.directive import (
 )
 from mkdocs_include_markdown_plugin.files_watcher import FilesWatcher
 from mkdocs_include_markdown_plugin.logger import logger
+from mkdocs_include_markdown_plugin.placeholders import (
+    escape_placeholders,
+    save_placeholder,
+    unescape_placeholders,
+)
 
 
 if TYPE_CHECKING:  # pragma: no cover
-    from typing import Literal, TypedDict
+    from typing import TypedDict
 
     from mkdocs.structure.pages import Page
 
@@ -46,23 +51,6 @@ if TYPE_CHECKING:  # pragma: no cover
     )
 
 
-# Placeholders (taken from Python-Markdown)
-STX = '\u0002'
-''' "Start of Text" marker for placeholder templates. '''
-ETX = '\u0003'
-''' "End of Text" marker for placeholder templates. '''
-INLINE_PLACEHOLDER_PREFIX = f'{STX}klzzwxh:'
-
-
-def build_placeholder(
-        num: int,
-        directive: Literal['include', 'include-markdown'],
-) -> str:
-    """Return a placeholder."""
-    directive_prefix = 'im' if directive == 'include-markdown' else 'i'
-    return f'{INLINE_PLACEHOLDER_PREFIX}{directive_prefix}{num}{ETX}'
-
-
 @dataclass
 class Settings:  # noqa: D101
     exclude: list[str] | None
@@ -98,8 +86,8 @@ def get_file_content(  # noqa: PLR0913, PLR0915
     else:
         settings_ignore_paths = []
 
-    new_found_include_contents: list[tuple[str, str]] = []
-    new_found_include_markdown_contents: list[tuple[str, str]] = []
+    markdown = escape_placeholders(markdown)
+    placeholders_contents: list[tuple[str, str]] = []
 
     def found_include_tag(  # noqa: PLR0912, PLR0915
             match: re.Match[str],
@@ -311,11 +299,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                     f' {readable_files_to_include}',
                 )
 
-        nonlocal new_found_include_contents
-        include_index = len(new_found_include_contents)
-        placeholder = build_placeholder(include_index, 'include')
-        new_found_include_contents.append((placeholder, text_to_include))
-        return placeholder
+        return save_placeholder(placeholders_contents, text_to_include)
 
     def found_include_markdown_tag(  # noqa: PLR0912, PLR0915
             match: re.Match[str],
@@ -607,15 +591,7 @@ def get_file_content(  # noqa: PLR0913, PLR0915
                     f' {readable_files_to_include}',
                 )
 
-        nonlocal new_found_include_markdown_contents
-        markdown_include_index = len(new_found_include_markdown_contents)
-        placeholder = build_placeholder(
-            markdown_include_index, 'include-markdown',
-        )
-        new_found_include_markdown_contents.append(
-            (placeholder, text_to_include),
-        )
-        return placeholder
+        return save_placeholder(placeholders_contents, text_to_include)
 
     # Replace contents by placeholders
     markdown = tags['include-markdown'].sub(
@@ -628,11 +604,9 @@ def get_file_content(  # noqa: PLR0913, PLR0915
     )
 
     # Replace placeholders by contents
-    for placeholder, text in new_found_include_contents:
+    for placeholder, text in placeholders_contents:
         markdown = markdown.replace(placeholder, text, 1)
-    for placeholder, text in new_found_include_markdown_contents:
-        markdown = markdown.replace(placeholder, text, 1)
-    return markdown
+    return unescape_placeholders(markdown)
 
 
 def on_page_markdown(
